@@ -2,12 +2,8 @@
 
 
 
-#%%
-
-
 
 import numpy as np
-import numpy 
 
 
 
@@ -32,6 +28,9 @@ def byte_conversion(x,properties):
   return conversion_final
 
 
+
+#%% GA functions
+
 # OBJECTIVE : MAXIMIZE
 def cal_pop_fitness(pop,properties,obj_fct):
     # Calculating the fitness value of each solution in the current population.
@@ -49,14 +48,8 @@ def cal_pop_fitness(pop,properties,obj_fct):
     return fitness
 
 
-def select_mating_pool(pop, fitness, num_parents):
-    # Selecting the best individuals in the current generation as parents for producing the offspring of the next generation.
-    parents = pop[ np.argsort(-fitness)[:num_parents] ]
-    return parents
-
-
 def crossover(parents, offspring_size):
-    offspring = numpy.empty(offspring_size)
+    offspring = np.empty(offspring_size)
 
     for k in range(offspring_size[0]):
         
@@ -69,7 +62,7 @@ def crossover(parents, offspring_size):
         parent2_idx = par_perm[1]
         
         # Random selection of genes
-        h = numpy.random.permutation(len(parents.T))
+        h = np.random.permutation(len(parents.T))
         pos1 = h[:int(len(parents.T)/2)]
         pos2 = h[int(len(parents.T)/2):]
 
@@ -83,18 +76,18 @@ def crossover(parents, offspring_size):
 
 def mutation(offspring_crossover,prop_mut):
     # Mutation changes a single gene in each offspring randomly.
-    nb_mut = int( numpy.sum(offspring_crossover*0+1)*prop_mut )
+    nb_mut = int( np.sum(offspring_crossover*0+1)*prop_mut )
     for _ in range(nb_mut):
         # The random value to be added to the gene.
-        rd1 = numpy.random.randint(0,len(offspring_crossover))
-        rd2 = numpy.random.randint(0,len(offspring_crossover.T))
-        offspring_crossover[rd1, rd2] = numpy.abs(offspring_crossover[rd1, rd2] - 1)
+        rd1 = np.random.randint(0,len(offspring_crossover))
+        rd2 = np.random.randint(0,len(offspring_crossover.T))
+        offspring_crossover[rd1, rd2] = np.abs(offspring_crossover[rd1, rd2] - 1)
 
     return offspring_crossover
 
 
 
-#%%
+#%% GA object
 
 
 class ga:
@@ -117,7 +110,7 @@ class ga:
         if( new_population ):
             0
         else:
-            new_population = numpy.random.randint(0,2, size=self.pop_size)
+            new_population = np.random.randint(0,2, size=self.pop_size)
             
         self.new_population = new_population
         
@@ -135,8 +128,8 @@ class ga:
                 print("Generation ", generation+1, " : ", -np.max(fitness))
                 
             # Selecting the best parents in the population for mating.
-            parents = select_mating_pool(self.new_population, fitness, 
-                                              self.num_parents_mating)
+            parents = self.new_population[ \
+                            np.argsort(-fitness)[:self.num_parents_mating] ]
             
             # Generating next generation using crossover.
             offspring_crossover = crossover(parents,
